use std::process;
use iss_locator::Location;

fn main() {

    let iss_location = match iss_locator::get_iss_location() {
        Ok(string) => string,
        Err(e) => panic!("Iss location aquisition failure: {e}"),
    };
    let local_location = match iss_locator::get_local_location() {
        Ok(string) => string,
        Err(e) => panic!("Local location aquisition failure: {e}"),
    };

    let iss: Location = Location::build(&iss_location).unwrap_or_else(|err| {
        eprintln!("{err}");
        process::exit(1);
    });
    let local: Location = Location::build(&local_location).unwrap_or_else(|err| {
        eprintln!("{err}");
        process::exit(1);
    });



    println!("local:{},{}",local.lat,local.long);
    println!(" iss :{},{}",iss.lat,iss.long);
    let distance = iss_locator::get_distance(local,iss);
    println!("distance: {:.3} km",distance);
    if  distance < 2246.6449 {
        println!("You are within ISS range");
    } else {
        println!("Outside of ISS range");
    }
}
